[][src]Function wascc_host::host::remove_actor

pub fn remove_actor(pk: &str) -> Result<()>

Removes an actor from the host. Stops the thread managing the actor and notifies all capability providers to free up any associated resources being used by the actor. Because this removal is asynchronous, the actors function might not immediately report the change.