[−][src]Function wascc_host::host::replace_actor
pub fn replace_actor(new_actor: Actor) -> Result<()>
Replaces one running actor with another live actor with no message loss. Note that the time it takes to perform this replacement can cause pending messages from capability providers (e.g. messages from subscriptions or HTTP requests) to build up in a backlog, so make sure the new actor can handle this stream of these delayed messages