[][src]Struct wascc_host::Actor

pub struct Actor { /* fields omitted */ }

An actor is a WebAssembly module that can consume capabilities exposed by capability providers

Methods

impl Actor[src]

pub fn from_bytes(buf: Vec<u8>) -> Result<Actor>[src]

Create an actor from the bytes (must be a signed module) of a WebAssembly module

pub fn from_file(path: impl AsRef<Path>) -> Result<Actor>[src]

Create an actor from a WebAssembly (.wasm) file

pub fn public_key(&self) -> String[src]

Obtain the actor's public key. This is globally unique identifier

pub fn name(&self) -> String[src]

The actor's human-friendly display name

pub fn issuer(&self) -> String[src]

Obtain the public key of the issuer of the actor's signed token

pub fn capabilities(&self) -> Vec<String>[src]

Obtain the list of capabilities declared in this actor's embedded token

pub fn tags(&self) -> Vec<String>[src]

Obtain the list of tags in the actor's token